@@ -6,7 +6,7 @@ use Mojo::UserAgent;
 use Mojo::Promise;
 use Mojo::IOLoop;
 
-our $VERSION = '0.27_1';
+our $VERSION = '0.27_2';
 
 # Todo:
 # - Better test tracking API support
@@ -111,8 +111,8 @@ sub register {
           return '';
         };
 
-        return b("<script src=\"$prot://${url}piwik.js\" async defer></script>" .
-                   '<script src="' . $c->url_for('piwik_track_script')->to_abs . '"></script>');
+        return b('<script src="' . $c->url_for('piwik_track_script')->to_abs . '"></script>' .
+                   "<script src=\"$prot://${url}piwik.js\" async defer></script>");
       }
 
       # Render opt-out tag
@@ -143,16 +143,14 @@ sub register {
 
       # Create piwik tag
       b(<<"SCRIPTTAG");
-<script type="text/javascript">var _paq=_paq||[];(function(){var
-u='http'+((document.location.protocol=='https:')?'s':'')+'://$url';
-with(_paq){push(['setSiteId',$site_id]);push(['setTrackerUrl',u+'piwik.php']);
-push(['trackPageView'])};var
-d=document,g=d.createElement('script'),s=d.getElementsByTagName('script')[0];
-if(!s){s=d.getElementsByTagName('head')[0].firstChild};
-with(g){type='text/javascript';defer=async=true;
-src=u+'piwik.js';s.parentNode.insertBefore(g,s)}})();$append</script>
-<noscript><img src="${prot}://${url}piwik.php?idSite=${site_id}&amp;rec=1" alt=""
-style="border:0" /></noscript>
+<script type="text/javascript">var _paq=window._paq=window._paq||[];
+_paq.push(['trackPageView']);_paq.push(['enableLinkTracking']);
+(function(){var u='http'+((document.location.protocol=='https:')?'s':'')+'://$url';
+_paq.push(['setTrackerUrl',u+'piwik.php']);_paq.push(['setSiteId',${site_id}]);
+var d=document,g=d.createElement('script'),s=d.getElementsByTagName('script')[0];
+g.type='text/javascript';g.async=true; g.src=u+'piwik.js'; s.parentNode.insertBefore(g,s);
+})();$append</script>
+<noscript><img src="${prot}://${url}piwik.php?idSite=${site_id}&amp;rec=1" alt="" style="border:0"/></noscript>
 SCRIPTTAG
     });
 
@@ -190,7 +188,7 @@ SCRIPTTAG
             # Render tracking code
             return $c->render(
               format => 'js',
-              text => 'var _paq=window._paq||[];' .
+              text => 'var _paq=window._paq=window._paq||[];' .
                 "_paq.push(['setTrackerUrl','$prot://${url}piwik.php']);" .
                 "_paq.push(['setSiteId',$site_id]);" .
                 q!_paq.push(['trackPageView']);! .
